@@ -2,6 +2,15 @@
 SEP="====================="
 FAIL="\n\n$SEP\n FAIL\n$SEP\n"
 
+echo Cleanup first
+rm -f alice.log bob.log charlie.log
+echo === del namespaces
+sudo ip netns del alice
+sudo ip netns del bob
+sudo ip netns del charlie
+sudo ip netns del backbone
+echo === done
+
 echo === add namespaces
 sudo ip netns add backbone
 sudo ip netns add alice
@@ -84,28 +93,105 @@ echo bob is client
 echo charlie is client
 echo expectation is, that after a while the ping succeeds: bob can reach charlie via the tunnel
 
-VERBOSITY=-vvv
-#tmux split-pane -h sh -c "sudo ip netns exec alice ../target/debug/wg_netmanager -vvvvv -c test.yaml wg0 10.1.1.1 alice || sleep 10"
-tmux split-pane -h -l 75% sudo ip netns exec alice ../target/debug/wg_netmanager $VERBOSITY -c test.yaml -t wg0 10.1.1.1 alice
-tmux split-pane -h -l 66% sudo ip netns exec bob ../target/debug/wg_netmanager $VERBOSITY -c test.yaml wg0 10.1.1.3 bob
+COLOR_ALICE=bg=#222240
+COLOR_BOB=bg=#402222
+COLOR_CHARLIE=bg=#224022
+
+FOCUS=ifconfig
+#FOCUS=wg
+tmux split-window -h sudo ip netns exec alice watch $FOCUS
+tmux select-pane -P $COLOR_ALICE
+tmux select-layout tiled
+tmux split-window -h sudo ip netns exec bob watch $FOCUS
+tmux select-pane -P $COLOR_BOB
+tmux select-layout tiled
+tmux split-window -h sudo ip netns exec charlie watch $FOCUS
+tmux select-pane -P $COLOR_CHARLIE
+tmux select-layout tiled
+
+tmux split-window -h sudo ip netns exec alice zsh
+tmux select-pane -P $COLOR_ALICE
+tmux select-layout tiled
+tmux split-window -h sudo ip netns exec bob zsh
+tmux select-pane -P $COLOR_BOB
+tmux select-layout tiled
+tmux split-window -h sudo ip netns exec charlie zsh
+tmux select-pane -P $COLOR_CHARLIE
+tmux select-layout tiled
+
+VERBOSITY=-vvvvv
+#tmux split-window -h sh -c "sudo ip netns exec alice ../target/debug/wg_netmanager -vvvvv -c test.yaml wg0 10.1.1.1 alice || sleep 10"
+tmux split-window -h sudo ip netns exec alice ../target/debug/wg_netmanager $VERBOSITY -c test.yaml  wg0 10.1.1.1 alice -l
+tmux select-pane -P $COLOR_ALICE
+tmux select-layout tiled
+tmux split-window -h sudo ip netns exec bob ../target/debug/wg_netmanager $VERBOSITY -c test.yaml wg0 10.1.1.3 bob -l || sleep 30
+tmux select-pane -P $COLOR_BOB
+tmux select-layout tiled
 sleep 20
-tmux split-pane -h sudo ip netns exec charlie ../target/debug/wg_netmanager $VERBOSITY -c test.yaml wg0 10.1.1.4 charlie
+
+echo
+echo ALICE   ==============================
+sudo ip netns exec alice ip route 
+sudo ip netns exec alice wg
+sudo ip netns exec alice sudo ifconfig wg0
+echo
+echo BOB     ==============================
+sudo ip netns exec bob ip route
+sudo ip netns exec bob wg
+sudo ip netns exec bob sudo ifconfig wg0
+echo
+
+tmux split-window -h sudo ip netns exec charlie ../target/debug/wg_netmanager $VERBOSITY -c test.yaml wg0 10.1.1.4 charlie -l
+tmux select-pane -P $COLOR_CHARLIE
+tmux select-layout tiled
+
+echo
+echo ALICE   ==============================
+sudo ip netns exec alice ip route 
+sudo ip netns exec alice wg
+sudo ip netns exec alice sudo ifconfig wg0
+echo
+echo BOB     ==============================
+sudo ip netns exec bob ip route
+sudo ip netns exec bob wg
+sudo ip netns exec bob sudo ifconfig wg0
+echo
+echo CHARLIE ==============================
+sudo ip netns exec charlie ip route
+sudo ip netns exec charlie wg
+sudo ip netns exec charlie sudo ifconfig wg0
+echo
+
 sleep 50
 
-echo ROUTE ALICE
+echo
+echo ALICE   ==============================
 sudo ip netns exec alice ip route 
-echo ROUTE BOB
+sudo ip netns exec alice wg
+sudo ip netns exec alice sudo ifconfig wg0
+echo
+echo BOB     ==============================
 sudo ip netns exec bob ip route
-echo ROUTE CHARLIE
+sudo ip netns exec bob wg
+sudo ip netns exec bob sudo ifconfig wg0
+echo
+echo CHARLIE ==============================
 sudo ip netns exec charlie ip route
+sudo ip netns exec charlie wg
+sudo ip netns exec charlie sudo ifconfig wg0
+echo
 
 sleep 10
+
 sudo ip netns exec bob ping -c 2 10.1.1.1 || echo -e $FAIL
 sudo ip netns exec charlie ping -c 2 10.1.1.1 || echo -e $FAIL
 sudo ip netns exec alice ping -c 2 10.1.1.3 || echo -e $FAIL
 sudo ip netns exec alice ping -c 2 10.1.1.4 || echo -e $FAIL
 sudo ip netns exec bob ping -c 2 10.1.1.4 || echo -e $FAIL
 
+echo enter ctrl-D
+cat
+
 echo ==== Kill the test subjects
 sudo ip netns exec alice killall sudo
 sudo ip netns exec bob killall sudo
