@@ -90,8 +90,8 @@ pub struct Node {
     is_static_peer: Option<bool>,
     pub wg_ip: Ipv4Addr,
     admin_port: u16,
-    hop_cnt: usize,
-    gateway: Option<Ipv4Addr>,
+    //hop_cnt: usize,
+    //gateway: Option<Ipv4Addr>,
     pub public_key: Option<PublicKeyWithTime>,
     known_in_s: usize,
     local_ip_list: Option<Vec<IpAddr>>,
@@ -106,8 +106,8 @@ impl Node {
             is_static_peer: None,
             wg_ip: ri.to,
             admin_port: ri.local_admin_port,
-            hop_cnt: ri.hop_cnt,
-            gateway: ri.gateway,
+            //hop_cnt: ri.hop_cnt,
+            //gateway: ri.gateway,
             public_key: None,
             known_in_s: 0,
             local_ip_list: None,
